#!/bin/sh

# File: xorg72setup.sh
# by ^thehatsrule^
# Quick script to set up your DSL environment for X.Org

. /etc/init.d/dsl-functions
backup_ext=".old"
fname="xorg72setup.sh"

out()
{
    printf "${BLUE}$*${NORMAL}\n"
}

err()
{
    printf "${RED}$*${NORMAL}\n" >&2
    exit 1
}

errusage()
{
    err "Usage: ${fname} { system | user } [ -f ]"
}

checkfile()
{
    if [ $# -ne 1 ]; then
        return 2
    fi
    checkfile=$1
    checkfile_backup=${checkfile}${backup_ext}

    if [ -e "$checkfile" ]; then
        grep "^### Edited by xorg72setup ###$" $checkfile >/dev/null && {
            out "$checkfile looks like it was already modified by this script."
            out "If you wish to reset it, please restore $checkfile (open with text file for more info)"
            return 1
        }
        out "Backing up $checkfile to $checkfile_backup"
        mv -f "$checkfile" "$checkfile_backup" || {
           err "Error backing up $checkfile"
        }
    fi
    return 0
}

LD_LIBRARY_PATH=/opt/xorg72/lib
export LD_LIBRARY_PATH

PATH=/opt/xorg72/bin:$PATH
export PATH

new_xconfig=~/xorg.conf.new
xconfig=/etc/X11/xorg.conf

xserverrc=~/.xserverrc
xinitrc=~/.xinitrc

if [ $# -ne 1 -a $# -ne 2 ]; then
    errusage
fi

### main ###

if [ "$1" = "system" ]; then

### system: xorg.conf ###

if [ `id -u` -ne 0 ]; then
    err "You need root privileges."
fi

if [ -e "$xconfig" ]; then
    if [ "$2" != "-f" ]; then
        err "$xconfig already found.  Pass -f to force overwrite and to continue."
    fi
    if [ ! -w "$xconfig" ]; then
        err "Cannot write to $xconfig."
    fi
fi

out "Trying to automatically configure your Xorg"
Xorg -configure 2>/dev/null || {
    err "Failed on Xorg -configure."
}

printf "Do you use a PS/2 Mouse? (y/...) "
read choice
if [ "$choice" = "y" ]; then
    out "Setting PS/2 Mouse"
    sed 's!\"/dev/input/mice\"!\"/dev/psaux\" # edited by xorg72setup!' "$new_xconfig" > "$xconfig"
else
    cp -f "$new_xconfig" "$xconfig"
fi

# cleanup
rm -f $new_xconfig

### done system: xorg.conf ###

elif [ "$1" = "user" ]; then

### user: .xserverrc .xinitrc ###

if [ `id -u` -eq 0 ]; then
    err "You probably don't want to run this with root privileges."
fi

# .xserverrc
checkfile "$xserverrc" && {

    out "Setting up .xserverrc"
    cat > $xserverrc << EOF
### Edited by xorg72setup ###
# Run xsetup.sh or use ${xserverrc}${backup_ext} to restore this file

exec /opt/xorg72/bin/X -nolisten tcp
EOF

    chmod +x "$xserverrc"
}

# .xinitrc
checkfile "$xinitrc" && {

    out "Setting up .xinitrc"
    cat > $xinitrc << EOF
### Edited by xorg72setup ###
# Use ${xinitrc}${backup_ext} or /etc/skel/.xinitrc to restore this file

LD_LIBRARY_PATH=$LD_LIBRARY_PATH:\$LD_LIBRARY_PATH
PATH=\$PATH:/opt/xorg72/bin
export LD_LIBRARY_PATH PATH

EOF

    cat "${xinitrc}${backup_ext}" >> "$xinitrc"
}

### done user: .xserverrc .xinitrc ###

else
    errusage
fi

